"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useBrix = void 0;

var _react = require("react");

var _BrixProvider = require("./BrixProvider");

var _helpers = require("./helpers");

var useBrix = function useBrix(path, notSetValue, customContext) {
  var state, setState;

  try {
    var context = (0, _react.useContext)(customContext || (0, _BrixProvider.getBrixContext)());
    state = context.state;
    setState = context.setState;
  } catch (err) {
    throw new Error('BrixProvider is not configured correctly in the app');
  }

  if (!state) {
    throw new Error('Context must have state property');
  }

  if (!setState) {
    throw new Error('Context must have setState function');
  }

  var value = state.getIn(path, notSetValue);

  var set = function set(updatedValue) {
    if (typeof updatedValue === 'function') {
      setState(function (current) {
        var currentValue = current.getIn(path, notSetValue);
        var newValue = updatedValue(currentValue);
        return current.setIn(path, (0, _helpers.coerceDataToImmutable)(newValue));
      });
    } else {
      setState(function (current) {
        return current.setIn(path, (0, _helpers.coerceDataToImmutable)(updatedValue));
      });
    }
  };

  return [value, set];
};

exports.useBrix = useBrix;